@@ -2,46 +2,46 @@ metabin <- function(event.e, n.e, event.c, n.c, studlab,
                     ##
                     data = NULL, subset = NULL,
                     ##
-                    method = ifelse(tau.common, "Inverse", .settings$method),
+                    method = ifelse(tau.common, "Inverse", gs("method")),
                     sm = 
                       ifelse(!is.na(charmatch(tolower(method), c("peto", "glmm"),
                                               nomatch = NA)),
-                             "OR", .settings$smbin),
-                    incr = .settings$incr, allincr = .settings$allincr,
-                    addincr = .settings$addincr, allstudies = .settings$allstudies,
-                    MH.exact = .settings$MH.exact, RR.cochrane = .settings$RR.cochrane,
+                             "OR", gs("smbin")),
+                    incr = gs("incr"), allincr = gs("allincr"),
+                    addincr = gs("addincr"), allstudies = gs("allstudies"),
+                    MH.exact = gs("MH.exact"), RR.cochrane = gs("RR.cochrane"),
                     model.glmm = "UM.FS",
                     ##
-                    level = .settings$level, level.comb = .settings$level.comb,
-                    comb.fixed = .settings$comb.fixed,
-                    comb.random = .settings$comb.random,
+                    level = gs("level"), level.comb = gs("level.comb"),
+                    comb.fixed = gs("comb.fixed"),
+                    comb.random = gs("comb.random"),
                     ##
-                    hakn = .settings$hakn,
+                    hakn = gs("hakn"),
                     method.tau =
                       ifelse(!is.na(charmatch(tolower(method), "glmm",
                                               nomatch = NA)),
-                             "ML", .settings$method.tau),
+                             "ML", gs("method.tau")),
                     tau.preset = NULL, TE.tau = NULL,
-                    tau.common = .settings$tau.common,
+                    tau.common = gs("tau.common"),
                     ##
-                    prediction = .settings$prediction,
-                    level.predict = .settings$level.predict,
+                    prediction = gs("prediction"),
+                    level.predict = gs("level.predict"),
                     ##
-                    method.bias = ifelse(sm == "OR", "score", .settings$method.bias),
+                    method.bias = ifelse(sm == "OR", "score", gs("method.bias")),
                     ##
-                    backtransf = .settings$backtransf,
-                    title = .settings$title, complab = .settings$complab,
+                    backtransf = gs("backtransf"),
+                    title = gs("title"), complab = gs("complab"),
                     outclab = "",
-                    label.e = .settings$label.e, label.c = .settings$label.c,
-                    label.left = .settings$label.left, label.right = .settings$label.right,
+                    label.e = gs("label.e"), label.c = gs("label.c"),
+                    label.left = gs("label.left"), label.right = gs("label.right"),
                     ##
-                    byvar, bylab, print.byvar = .settings$print.byvar,
-                    byseparator = .settings$byseparator,
+                    byvar, bylab, print.byvar = gs("print.byvar"),
+                    byseparator = gs("byseparator"),
                     ##
-                    print.CMH = .settings$print.CMH,
+                    print.CMH = gs("print.CMH"),
                     ##
-                    keepdata = .settings$keepdata,
-                    warn = .settings$warn,
+                    keepdata = gs("keepdata"),
+                    warn = gs("warn"),
                     ...
                     ) {
   
@@ -80,7 +80,8 @@ metabin <- function(event.e, n.e, event.c, n.c, studlab,
   if (method == "GLMM") {
     is.installed.package("lme4", fun, "method", " = \"GLMM\"")
     is.installed.package("numDeriv", fun, "method", " = \"GLMM\"")
-    is.installed.package("metafor", fun, "method", " = \"GLMM\"")
+    is.installed.package("metafor", fun, "method", " = \"GLMM\"",
+                         version = .settings$metafor)
   }
   ##
   chklogical(allincr)
@@ -320,7 +321,7 @@ metabin <- function(event.e, n.e, event.c, n.c, studlab,
     else {
       if (sm == "OR")
         incl <- ifelse((event.c == 0   & event.e == 0) |
-                         (event.c == n.c & event.e == n.e), NA, 1)
+                       (event.c == n.c & event.e == n.e), NA, 1)
       if (sm == "RR")
         incl <- ifelse((event.c == 0 & event.e == 0), NA, 1)
     }
@@ -367,9 +368,9 @@ metabin <- function(event.e, n.e, event.c, n.c, studlab,
   if (sparse & sm %in% c("RR", "OR") & !(method %in% c("Peto", "GLMM"))) {
     sel.doublezeros <- switch(sm,
                               OR = (event.e == 0   & event.c ==   0) |
-                                (event.c == n.c & event.e == n.e),
+                                   (event.c == n.c & event.e == n.e),
                               RR = (event.c == 0 & event.e == 0))
-    if (any(sel.doublezeros))
+    if (any(sel.doublezeros, na.rm = TRUE))
       doublezeros <- TRUE
   }
   ##
@@ -628,7 +629,8 @@ metabin <- function(event.e, n.e, event.c, n.c, studlab,
     glmm.fixed <- metafor::rma.glmm(ai = event.e, n1i = n.e,
                                     ci = event.c, n2i = n.c,
                                     method = "FE",
-                                    tdist = hakn, level = 100 * level.comb,
+                                    test = ifelse(hakn, "t", "z"),
+                                    level = 100 * level.comb,
                                     measure = "OR", model = model.glmm,
                                     ...)
     ##
@@ -721,7 +723,8 @@ metabin <- function(event.e, n.e, event.c, n.c, studlab,
     glmm.random <- metafor::rma.glmm(ai = event.e, n1i = n.e,
                                      ci = event.c, n2i = n.c,
                                      method = method.tau,
-                                     tdist = hakn, level = 100 * level.comb,
+                                     test = ifelse(hakn, "t", "z"),
+                                     level = 100 * level.comb,
                                      measure = "OR", model = model.glmm,
                                      ...)
     ##
