@@ -8,15 +8,15 @@ print.meta <- function(x,
                        pscale = x$pscale,
                        irscale = x$irscale,
                        irunit = x$irunit,
-                       digits = .settings$digits,
-                       digits.se = .settings$digits.se,
-                       digits.zval = .settings$digits.zval,
-                       digits.Q = .settings$digits.Q,
-                       digits.tau2 = .settings$digits.tau2,
-                       digits.H = .settings$digits.H,
-                       digits.I2 = .settings$digits.I2,
-                       digits.prop = .settings$digits.prop,
-                       digits.weight = .settings$digits.weight,
+                       digits = gs("digits"),
+                       digits.se = gs("digits.se"),
+                       digits.zval = gs("digits.zval"),
+                       digits.Q = gs("digits.Q"),
+                       digits.tau2 = gs("digits.tau2"),
+                       digits.H = gs("digits.H"),
+                       digits.I2 = gs("digits.I2"),
+                       digits.prop = gs("digits.prop"),
+                       digits.weight = gs("digits.weight"),
                        warn.backtransf = FALSE,
                        ...
                        ) {
